OC.L10N.register(
    "recommendations",
    {
    "Recently commented" : "Commentés récemment",
    "Recently edited" : "Modifiés récemment",
    "Recently shared" : "Partagés récemment",
    "Recommendations" : "Recommandations",
    "Shows recommended files" : "Affiche les fichiers recommandés",
    "Shows recommended files for quick access of files and folders with recent activity" : "Affiche les fichiers recommandés pour un accès rapide aux fichiers et dossiers ayant une activité récente",
    "Enabled" : "Activé"
},
"nplurals=2; plural=(n > 1);");
